.. _installation-section:

============
Installation
============

.. warning:: Pharmpy requires python 3.6 or later,
    and is currently tested on python 3.6, 3.7 and 3.8 on Linux.

At the command line, install latest build with::

    pip3 install dist/pharmpy-0.3.0.tar.gz

Or, development code in ``src/``::

    pip3 install -e src/pharmpy

Or, just use ``setup.py``::

    python3 setup.py install
